package com.yijia.station.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yijia.station.mapper.PayOrderMapper;
import com.yijia.station.domain.PayOrder;
import com.yijia.station.service.IPayOrderService;

/**
 * 订单支付Service业务层处理
 * 
 * @author yijia
 * @date 2020-12-10
 */
@Service
public class PayOrderServiceImpl implements IPayOrderService 
{
    @Autowired
    private PayOrderMapper payOrderMapper;

    /**
     * 查询订单支付
     * 
     * @param orderId 订单支付ID
     * @return 订单支付
     */
    @Override
    public PayOrder selectPayOrderById(Long orderId)
    {
        return payOrderMapper.selectPayOrderById(orderId);
    }

    /**
     * 查询订单支付列表
     * 
     * @param payOrder 订单支付
     * @return 订单支付
     */
    @Override
    public List<PayOrder> selectPayOrderList(PayOrder payOrder)
    {
        return payOrderMapper.selectPayOrderList(payOrder);
    }

    /**
     * 新增订单支付
     * 
     * @param payOrder 订单支付
     * @return 结果
     */
    @Override
    public int insertPayOrder(PayOrder payOrder)
    {
        return payOrderMapper.insertPayOrder(payOrder);
    }

    /**
     * 修改订单支付
     * 
     * @param payOrder 订单支付
     * @return 结果
     */
    @Override
    public int updatePayOrder(PayOrder payOrder)
    {
        return payOrderMapper.updatePayOrder(payOrder);
    }

    /**
     * 批量删除订单支付
     * 
     * @param orderIds 需要删除的订单支付ID
     * @return 结果
     */
    @Override
    public int deletePayOrderByIds(Long[] orderIds)
    {
        return payOrderMapper.deletePayOrderByIds(orderIds);
    }

    /**
     * 删除订单支付信息
     * 
     * @param orderId 订单支付ID
     * @return 结果
     */
    @Override
    public int deletePayOrderById(Long orderId)
    {
        return payOrderMapper.deletePayOrderById(orderId);
    }
}
