package com.yijia.station.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yijia.station.mapper.StationOilPriceAdjustMapper;
import com.yijia.station.domain.StationOilPriceAdjust;
import com.yijia.station.service.IStationOilPriceAdjustService;

/**
 * 油品调价信息Service业务层处理
 * 
 * @author yijia
 * @date 2020-12-09
 */
@Service
public class StationOilPriceAdjustServiceImpl implements IStationOilPriceAdjustService 
{
    @Autowired
    private StationOilPriceAdjustMapper stationOilPriceAdjustMapper;

    /**
     * 查询油品调价信息
     * 
     * @param adjustPriceId 油品调价信息ID
     * @return 油品调价信息
     */
    @Override
    public StationOilPriceAdjust selectStationOilPriceAdjustById(Long adjustPriceId)
    {
        return stationOilPriceAdjustMapper.selectStationOilPriceAdjustById(adjustPriceId);
    }

    /**
     * 查询油品调价信息列表
     * 
     * @param stationOilPriceAdjust 油品调价信息
     * @return 油品调价信息
     */
    @Override
    public List<StationOilPriceAdjust> selectStationOilPriceAdjustList(StationOilPriceAdjust stationOilPriceAdjust)
    {
        return stationOilPriceAdjustMapper.selectStationOilPriceAdjustList(stationOilPriceAdjust);
    }

    /**
     * 新增油品调价信息
     * 
     * @param stationOilPriceAdjust 油品调价信息
     * @return 结果
     */
    @Override
    public int insertStationOilPriceAdjust(StationOilPriceAdjust stationOilPriceAdjust)
    {
        return stationOilPriceAdjustMapper.insertStationOilPriceAdjust(stationOilPriceAdjust);
    }

    /**
     * 修改油品调价信息
     * 
     * @param stationOilPriceAdjust 油品调价信息
     * @return 结果
     */
    @Override
    public int updateStationOilPriceAdjust(StationOilPriceAdjust stationOilPriceAdjust)
    {
        return stationOilPriceAdjustMapper.updateStationOilPriceAdjust(stationOilPriceAdjust);
    }

    /**
     * 批量删除油品调价信息
     * 
     * @param adjustPriceIds 需要删除的油品调价信息ID
     * @return 结果
     */
    @Override
    public int deleteStationOilPriceAdjustByIds(Long[] adjustPriceIds)
    {
        return stationOilPriceAdjustMapper.deleteStationOilPriceAdjustByIds(adjustPriceIds);
    }

    /**
     * 删除油品调价信息信息
     * 
     * @param adjustPriceId 油品调价信息ID
     * @return 结果
     */
    @Override
    public int deleteStationOilPriceAdjustById(Long adjustPriceId)
    {
        return stationOilPriceAdjustMapper.deleteStationOilPriceAdjustById(adjustPriceId);
    }
}
